/**
 * @file transport.h
 *
 * Support for transport property calculation from C++ application programs.
 * This header file includes headers needed to create and use objects for
 * evaluating transport properties.
 */

#ifndef CT_TRANSPORT_INCL
#define CT_TRANSPORT_INCL

#pragma message("warning: transport.h is deprecated and will be removed after " \
                "Cantera 3.2. Use core.h and/or transport/TransportFactory.h instead.")

#include "transport/TransportFactory.h"

#endif
